diff --git a/all.sln b/all.sln
index 228047852..604bb51fb 100644
--- a/all.sln
+++ b/all.sln
@@ -118,6 +118,8 @@ Project("{9A19103F-16F7-4668-BE54-9A1E7A4F7556}") = "Dapr.E2E.Test.Actors.Genera
EndProject
Project("{9A19103F-16F7-4668-BE54-9A1E7A4F7556}") = "Cryptography", "examples\Client\Cryptography\Cryptography.csproj", "{C74FBA78-13E8-407F-A173-4555AEE41FF3}"
EndProject
+Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "Dapr.Protos", "src\Dapr.Protos\Dapr.Protos.csproj", "{DFBABB04-50E9-42F6-B470-310E1B545638}"
+EndProject
Global
GlobalSection(SolutionConfigurationPlatforms) = preSolution
Debug|Any CPU = Debug|Any CPU
@@ -290,6 +292,10 @@ Global
{C74FBA78-13E8-407F-A173-4555AEE41FF3}.Debug|Any CPU.Build.0 = Debug|Any CPU
{C74FBA78-13E8-407F-A173-4555AEE41FF3}.Release|Any CPU.ActiveCfg = Release|Any CPU
{C74FBA78-13E8-407F-A173-4555AEE41FF3}.Release|Any CPU.Build.0 = Release|Any CPU
+ {DFBABB04-50E9-42F6-B470-310E1B545638}.Debug|Any CPU.ActiveCfg = Debug|Any CPU
+ {DFBABB04-50E9-42F6-B470-310E1B545638}.Debug|Any CPU.Build.0 = Debug|Any CPU
+ {DFBABB04-50E9-42F6-B470-310E1B545638}.Release|Any CPU.ActiveCfg = Release|Any CPU
+ {DFBABB04-50E9-42F6-B470-310E1B545638}.Release|Any CPU.Build.0 = Release|Any CPU
EndGlobalSection
GlobalSection(SolutionProperties) = preSolution
HideSolutionNode = FALSE
@@ -343,6 +349,7 @@ Global
{AF89083D-4715-42E6-93E9-38497D12A8A6} = {DD020B34-460F-455F-8D17-CF4A949F100B}
{B5CDB0DC-B26D-48F1-B934-FE5C1C991940} = {DD020B34-460F-455F-8D17-CF4A949F100B}
{C74FBA78-13E8-407F-A173-4555AEE41FF3} = {A7F41094-8648-446B-AECD-DCC2CC871F73}
+ {DFBABB04-50E9-42F6-B470-310E1B545638} = {27C5D71D-0721-4221-9286-B94AB07B58CF}
EndGlobalSection
GlobalSection(ExtensibilityGlobals) = postSolution
SolutionGuid = {65220BF2-EAE1-4CB2-AA58-EBE80768CB40}
diff --git a/examples/AspNetCore/GrpcServiceSample/GrpcServiceSample.csproj b/examples/AspNetCore/GrpcServiceSample/GrpcServiceSample.csproj
index 6084df013..2319f6a56 100644
--- a/examples/AspNetCore/GrpcServiceSample/GrpcServiceSample.csproj
+++ b/examples/AspNetCore/GrpcServiceSample/GrpcServiceSample.csproj
@@ -19,6 +19,7 @@
+
diff --git a/src/Dapr.Client/Dapr.Client.csproj b/src/Dapr.Client/Dapr.Client.csproj
index e091078c0..52f928c81 100644
--- a/src/Dapr.Client/Dapr.Client.csproj
+++ b/src/Dapr.Client/Dapr.Client.csproj
@@ -5,12 +5,6 @@
-
-
-
-
-
-
This package contains the reference assemblies for developing services using Dapr.
@@ -21,9 +15,8 @@
-
-
+
diff --git a/src/Dapr.Protos/Dapr.Protos.csproj b/src/Dapr.Protos/Dapr.Protos.csproj
new file mode 100644
index 000000000..8a8804b22
--- /dev/null
+++ b/src/Dapr.Protos/Dapr.Protos.csproj
@@ -0,0 +1,22 @@
+
+
+
+ enable
+ enable
+ This package contains the reference protos used by develop services using Dapr.
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/src/Dapr.Client/Protos/dapr/proto/common/v1/common.proto b/src/Dapr.Protos/Protos/dapr/proto/common/v1/common.proto
similarity index 98%
rename from src/Dapr.Client/Protos/dapr/proto/common/v1/common.proto
rename to src/Dapr.Protos/Protos/dapr/proto/common/v1/common.proto
index 4acf9159d..0eb882b89 100644
--- a/src/Dapr.Client/Protos/dapr/proto/common/v1/common.proto
+++ b/src/Dapr.Protos/Protos/dapr/proto/common/v1/common.proto
@@ -1,4 +1,4 @@
-/*
+/*
Copyright 2021 The Dapr Authors
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
@@ -26,7 +26,7 @@ option go_package = "github.com/dapr/dapr/pkg/proto/common/v1;common";
// when Dapr runtime delivers HTTP content.
//
// For example, when callers calls http invoke api
-// POST http://localhost:3500/v1.0/invoke//method/?query1=value1&query2=value2
+// `POST http://localhost:3500/v1.0/invoke//method/?query1=value1&query2=value2`
//
// Dapr runtime will parse POST as a verb and extract querystring to quersytring map.
message HTTPExtension {
diff --git a/src/Dapr.Client/Protos/dapr/proto/dapr/v1/appcallback.proto b/src/Dapr.Protos/Protos/dapr/proto/runtime/v1/appcallback.proto
similarity index 98%
rename from src/Dapr.Client/Protos/dapr/proto/dapr/v1/appcallback.proto
rename to src/Dapr.Protos/Protos/dapr/proto/runtime/v1/appcallback.proto
index a86040364..51dee5539 100644
--- a/src/Dapr.Client/Protos/dapr/proto/dapr/v1/appcallback.proto
+++ b/src/Dapr.Protos/Protos/dapr/proto/runtime/v1/appcallback.proto
@@ -1,4 +1,4 @@
-/*
+/*
Copyright 2021 The Dapr Authors
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
@@ -58,7 +58,7 @@ service AppCallbackHealthCheck {
// AppCallbackAlpha V1 is an optional extension to AppCallback V1 to opt
// for Alpha RPCs.
service AppCallbackAlpha {
- // Subscribes bulk events from Pubsub
+ // Subscribes bulk events from Pubsub
rpc OnBulkTopicEventAlpha1(TopicEventBulkRequest) returns (TopicEventBulkResponse) {}
// Sends job back to the app's endpoint at trigger time.
@@ -185,14 +185,14 @@ message TopicEventBulkRequestEntry {
// content type of the event contained.
string content_type = 4;
-
+
// The metadata associated with the event.
map metadata = 5;
}
// TopicEventBulkRequest represents request for bulk message
message TopicEventBulkRequest {
- // Unique identifier for the bulk request.
+ // Unique identifier for the bulk request.
string id = 1;
// The list of items inside this bulk request.
@@ -203,10 +203,10 @@ message TopicEventBulkRequest {
// The pubsub topic which publisher sent to.
string topic = 4;
-
+
// The name of the pubsub the publisher sent to.
string pubsub_name = 5;
-
+
// The type of event related to the originating occurrence.
string type = 6;
@@ -310,8 +310,8 @@ message TopicRoutes {
message TopicRule {
// The optional CEL expression used to match the event.
- // If the match is not specified, then the route is considered
- // the default.
+ // If the match is not specified, then the route is considered
+ // the default.
string match = 1;
// The path used to identify matches for this subscription.
diff --git a/test/Dapr.AspNetCore.IntegrationTest/Dapr.AspNetCore.IntegrationTest.csproj b/test/Dapr.AspNetCore.IntegrationTest/Dapr.AspNetCore.IntegrationTest.csproj
index ace894a4f..1a5ee2a1b 100644
--- a/test/Dapr.AspNetCore.IntegrationTest/Dapr.AspNetCore.IntegrationTest.csproj
+++ b/test/Dapr.AspNetCore.IntegrationTest/Dapr.AspNetCore.IntegrationTest.csproj
@@ -24,6 +24,7 @@
+
diff --git a/test/Dapr.AspNetCore.Test/Dapr.AspNetCore.Test.csproj b/test/Dapr.AspNetCore.Test/Dapr.AspNetCore.Test.csproj
index a76288891..9135e63d4 100644
--- a/test/Dapr.AspNetCore.Test/Dapr.AspNetCore.Test.csproj
+++ b/test/Dapr.AspNetCore.Test/Dapr.AspNetCore.Test.csproj
@@ -21,6 +21,7 @@
+
\ No newline at end of file
diff --git a/test/Dapr.Client.Test/Dapr.Client.Test.csproj b/test/Dapr.Client.Test/Dapr.Client.Test.csproj
index 9a8d91c79..f7f2b9122 100644
--- a/test/Dapr.Client.Test/Dapr.Client.Test.csproj
+++ b/test/Dapr.Client.Test/Dapr.Client.Test.csproj
@@ -33,6 +33,7 @@
+
diff --git a/test/Dapr.Extensions.Configuration.Test/Dapr.Extensions.Configuration.Test.csproj b/test/Dapr.Extensions.Configuration.Test/Dapr.Extensions.Configuration.Test.csproj
index 0c7bce286..854288178 100644
--- a/test/Dapr.Extensions.Configuration.Test/Dapr.Extensions.Configuration.Test.csproj
+++ b/test/Dapr.Extensions.Configuration.Test/Dapr.Extensions.Configuration.Test.csproj
@@ -22,6 +22,7 @@
+
diff --git a/src/Dapr.Client/Protos/dapr/proto/dapr/v1/dapr.proto b/src/Dapr.Protos/Protos/dapr/proto/runtime/v1/dapr.proto
similarity index 95%
rename from src/Dapr.Client/Protos/dapr/proto/dapr/v1/dapr.proto
rename to src/Dapr.Protos/Protos/dapr/proto/runtime/v1/dapr.proto
index 4185fb391..ecf0f76f7 100644
--- a/src/Dapr.Client/Protos/dapr/proto/dapr/v1/dapr.proto
+++ b/src/Dapr.Protos/Protos/dapr/proto/runtime/v1/dapr.proto
@@ -1,4 +1,4 @@
-/*
+/*
Copyright 2021 The Dapr Authors
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
@@ -19,7 +19,7 @@ import "google/protobuf/any.proto";
import "google/protobuf/empty.proto";
import "google/protobuf/timestamp.proto";
import "dapr/proto/common/v1/common.proto";
-import "dapr/proto/dapr/v1/appcallback.proto";
+import "dapr/proto/runtime/v1/appcallback.proto";
option csharp_namespace = "Dapr.Client.Autogen.Grpc.v1";
option java_outer_classname = "DaprProtos";
@@ -61,7 +61,7 @@ service Dapr {
// SubscribeTopicEventsAlpha1 subscribes to a PubSub topic and receives topic
// events from it.
- rpc SubscribeTopicEventsAlpha1(stream SubscribeTopicEventsRequestAlpha1) returns (stream TopicEventRequest) {}
+ rpc SubscribeTopicEventsAlpha1(stream SubscribeTopicEventsRequestAlpha1) returns (stream SubscribeTopicEventsResponseAlpha1) {}
// Invokes binding data to specific output bindings
rpc InvokeBinding(InvokeBindingRequest) returns (InvokeBindingResponse) {}
@@ -428,17 +428,17 @@ message BulkPublishResponseFailedEntry {
// SubscribeTopicEventsRequestAlpha1 is a message containing the details for
// subscribing to a topic via streaming.
// The first message must always be the initial request. All subsequent
// messages must be event responses.
message SubscribeTopicEventsRequestAlpha1 {
oneof subscribe_topic_events_request_type {
- SubscribeTopicEventsInitialRequestAlpha1 initial_request = 1;
- SubscribeTopicEventsResponseAlpha1 event_response = 2;
+ SubscribeTopicEventsRequestInitialAlpha1 initial_request = 1;
+ SubscribeTopicEventsRequestProcessedAlpha1 event_processed = 2;
}
}
-// SubscribeTopicEventsInitialRequestAlpha1 is the initial message containing the
-// details for subscribing to a topic via streaming.
-message SubscribeTopicEventsInitialRequestAlpha1 {
+// SubscribeTopicEventsRequestInitialAlpha1 is the initial message containing
+// the details for subscribing to a topic via streaming.
+message SubscribeTopicEventsRequestInitialAlpha1 {
// The name of the pubsub component
string pubsub_name = 1;
@@ -456,9 +456,9 @@ message SubscribeTopicEventsInitialRequestAlpha1 {
optional string dead_letter_topic = 4;
}
// SubscribeTopicEventsResponseAlpha1 is a message containing the result of a
// subscription to a topic.
-message SubscribeTopicEventsResponseAlpha1 {
+message SubscribeTopicEventsRequestProcessedAlpha1 {
// id is the unique identifier for the subscription request.
string id = 1;
@@ -466,6 +466,21 @@ message SubscribeTopicEventsResponseAlpha1 {
TopicEventResponse status = 2;
}
+
+// SubscribeTopicEventsResponseAlpha1 is a message returned from daprd
+// when subscribing to a topic via streaming.
+message SubscribeTopicEventsResponseAlpha1 {
+ oneof subscribe_topic_events_response_type {
+ SubscribeTopicEventsResponseInitialAlpha1 initial_response = 1;
+ TopicEventRequest event_message = 2;
+ }
+}
+
+// SubscribeTopicEventsResponseInitialAlpha1 is the initial response from daprd
+// when subscribing to a topic.
+message SubscribeTopicEventsResponseInitialAlpha1 {}
+
+
// InvokeBindingRequest is the message to send data to output bindings
message InvokeBindingRequest {
// The name of the output binding to invoke.
@@ -478,6 +493,7 @@ message InvokeBindingRequest {
//
// Common metadata property:
// - ttlInSeconds : the time to live in seconds for the message.
+ //
// If set in the binding definition will cause all messages to
// have a default time to live. The message ttl overrides any value
// in the binding definition.
@@ -824,11 +840,11 @@ message TryLockRequest {
//
// The reason why we don't make it automatically generated is:
// 1. If it is automatically generated,there must be a 'my_lock_owner_id' field in the response.
- // This name is so weird that we think it is inappropriate to put it into the api spec
+ // This name is so weird that we think it is inappropriate to put it into the api spec
// 2. If we change the field 'my_lock_owner_id' in the response to 'lock_owner',which means the current lock owner of this lock,
- // we find that in some lock services users can't get the current lock owner.Actually users don't need it at all.
+ // we find that in some lock services users can't get the current lock owner.Actually users don't need it at all.
// 3. When reentrant lock is needed,the existing lock_owner is required to identify client and check "whether this client can reenter this lock".
- // So this field in the request shouldn't be removed.
+ // So this field in the request shouldn't be removed.
string lock_owner = 3 [json_name = "lockOwner"];
// Required. The time before expiry.The time unit is second.
@@ -865,7 +881,7 @@ message SubtleGetKeyRequest {
// JSON (JSON Web Key) as string
JSON = 1;
}
-
+
// Name of the component
string component_name = 1 [json_name="componentName"];
// Name (or name/version) of the key to use in the key vault
@@ -1047,7 +1063,7 @@ message EncryptRequestOptions {
// If true, the encrypted document does not contain a key reference.
// In that case, calls to the Decrypt method must provide a key reference (name or name/version).
// Defaults to false.
- bool omit_decryption_key_name = 11 [json_name="omitDecryptionKeyName"];
+ bool omit_decryption_key_name = 11 [json_name="omitDecryptionKeyName"];
// Key reference to embed in the encrypted document (name or name/version).
// This is helpful if the reference of the key used to decrypt the document is different from the one used to encrypt it.
// If unset, uses the reference of the key used to encrypt the document (this is the default behavior).
@@ -1196,14 +1212,14 @@ message Job {
// "0 15 3 * * *" - every day at 03:15
//
// Period string expressions:
- // Entry | Description | Equivalent To
- // ----- | ----------- | -------------
- // @every | Run every (e.g. '@every 1h30m') | N/A
- // @yearly (or @annually) | Run once a year, midnight, Jan. 1st | 0 0 0 1 1 *
- // @monthly | Run once a month, midnight, first of month | 0 0 0 1 * *
- // @weekly | Run once a week, midnight on Sunday | 0 0 0 * * 0
- // @daily (or @midnight) | Run once a day, midnight | 0 0 0 * * *
- // @hourly | Run once an hour, beginning of hour | 0 0 * * * *
+ // Entry | Description | Equivalent To
+ // ----- | ----------- | -------------
+ // @every `` | Run every `` (e.g. '@every 1h30m') | N/A
+ // @yearly (or @annually) | Run once a year, midnight, Jan. 1st | 0 0 0 1 1 *
+ // @monthly | Run once a month, midnight, first of month | 0 0 0 1 * *
+ // @weekly | Run once a week, midnight on Sunday | 0 0 0 * * 0
+ // @daily (or @midnight) | Run once a day, midnight | 0 0 0 * * *
+ // @hourly | Run once an hour, beginning of hour | 0 0 * * * *
optional string schedule = 2 [json_name = "schedule"];
// repeats is the optional number of times in which the job should be
@@ -1258,4 +1274,4 @@ message DeleteJobRequest {
// DeleteJobResponse is the message response to delete the job by name.
message DeleteJobResponse {
// Empty
-}
+}
\ No newline at end of file
@@ -428,17 +428,17 @@ message BulkPublishResponseFailedEntry {
// subscribing to a topic via streaming.
// The first message must always be the initial request. All subsequent
-// messages must be event responses.
+// messages must be event processed responses.
message SubscribeTopicEventsRequestAlpha1 {
oneof subscribe_topic_events_request_type {
@@ -456,9 +456,9 @@ message SubscribeTopicEventsInitialRequestAlpha1 {
optional string dead_letter_topic = 4;
}
-// SubscribeTopicEventsResponseAlpha1 is a message containing the result of a
+// SubscribeTopicEventsRequestProcessedAlpha1 is the message containing the
// subscription to a topic.